#[repr(u8)]pub enum Periph2ClkSelBusy {
PERIPH2_CLK_SEL_BUSY_0 = 0,
PERIPH2_CLK_SEL_BUSY_1 = 1,
}Variants
PERIPH2_CLK_SEL_BUSY_0 = 0
mux is not busy and its value represents the actual division.
PERIPH2_CLK_SEL_BUSY_1 = 1
mux is busy with handshake process with module. The value read in the periph2_clk_sel represents the previous value of select, and after the handshake periph2_clk_sel value will be applied.
Implementations