nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

SemcPodfBusy

Enum SemcPodfBusy 

#[repr(u8)]
pub enum SemcPodfBusy { SEMC_PODF_BUSY_0 = 0, SEMC_PODF_BUSY_1 = 1, }

Variants



SEMC_PODF_BUSY_0 = 0

divider is not busy and its value represents the actual division.



SEMC_PODF_BUSY_1 = 1

divider is busy with handshake process with module. The value read in the divider represents the previous value of the division factor, and after the handshake the written value of the semc_podf will be applied.

Implementations

Source

impl SemcPodfBusy

pub const fn from_bits(val: u8) -> SemcPodfBusy

pub const fn to_bits(self) -> u8